/*
 * (C) Copyright 2000
 * Subodh Nijsure, SkyStream Networks, snijsure@skystream.com
 *
 * See file CREDITS for list of people who contributed to this
 * project.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

#ifndef	_CMD_REGINFO_H_
#define	_CMD_REGINFO_H_

#if (defined(CONFIG_5xx) || defined(CONFIG_8xx) || defined(CONFIG_405GP) || defined(CONFIG_405EP)) && \
    (CONFIG_COMMANDS & CFG_CMD_REGINFO)
#define	CMD_TBL_REGINFO	MK_CMD_TBL_ENTRY(					\
	"reginfo",	3,	2,	1,	do_reginfo,			\
	"reginfo - print register information\n",				\
),

int do_reginfo (cmd_tbl_t *cmdtp, int flag, int argc, char *argv[]);

#else
#define CMD_TBL_REGINFO
#endif	/* CONFIG_COMMANDS && CFG_CMD_REGINFO */

#endif	/* _CMD_REGINFO_H_ */
